==> haskell-yesod-core-1.6.26.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.26.0
visibility:           public
id:                   yesod-core-1.6.26.0-2YUT5dn4HXTEvKAeT5KKAw
key:                  yesod-core-1.6.26.0-2YUT5dn4HXTEvKAeT5KKAw
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  1d83a6f15892819f31da668730a9daf0
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.26.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.26.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.26.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.26.0-2YUT5dn4HXTEvKAeT5KKAw
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj
    attoparsec-aeson-2.1.0.0-JXDBZK9SCy153xgj2WPTm0
    auto-update-0.1.6-1lOVSbLNGxnLZ9UaTRlWtc base-4.17.2.1
    blaze-html-0.9.2.0-4j6jevlp0QUEusbPG23DSX
    blaze-markup-0.8.3.0-E3xIpXEfOxQ70jxLTxkTyw bytestring-0.11.5.3
    case-insensitive-1.2.1.0-BBd0FN3VG9pHwba5nfbZ8v
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    clientsession-0.9.2.0-8FF7n7u1ysRVuzYlvJFvN
    conduit-1.3.6.1-86fl8mgs0PcICSp2A4xyva
    conduit-extra-1.3.6-E0orZ3VxcGP3f1095Bo2Ko containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm deepseq-1.4.8.0
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    fast-logger-3.1.2-GE9ux6OeXUTBZ4Gqb6r8t8
    http-types-0.12.4-1DZFzfvJVK9AHfgKU8FkY3
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-logger-0.3.41-8f5WrtCEAAaJAwYfnZ9RTa mtl-2.2.2
    parsec-3.1.16.1 path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    primitive-0.8.0.0-CgxKCR9ULfZ73CnNdOTvCD
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD
    shakespeare-2.1.0.1-AD7UIKDnOIUxdqDNmAzti template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.3-9Tj09IRjFnyE6cgV0AVkT
    unliftio-0.2.25.1-LfkN9oBuVsC1PSAv8s4AS5
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O
    wai-3.2.4-LaZv3Kj0Ed9gV12y2mMCG
    wai-extra-3.1.16-LREM6CQuOwCLYxhEeUHpj
    wai-logger-2.5.0-IEJ1BDozKwc6Z14LwYmPNh
    warp-3.3.30-Ko8TMDj1XRcF7NHzWysOJy
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.6.26.0-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.26.0
visibility:           public
id:                   yesod-core-1.6.26.0-1gQhTetVhel7YKGUqnl4Yf
key:                  yesod-core-1.6.26.0-1gQhTetVhel7YKGUqnl4Yf
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  8317853c77f4c5334e056473be8e3fa2
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.26.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.26.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-core-1.6.26.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.26.0-1gQhTetVhel7YKGUqnl4Yf
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj
    attoparsec-aeson-2.1.0.0-JXDBZK9SCy153xgj2WPTm0
    auto-update-0.1.6-1lOVSbLNGxnLZ9UaTRlWtc base-4.17.2.1
    blaze-html-0.9.2.0-4j6jevlp0QUEusbPG23DSX
    blaze-markup-0.8.3.0-E3xIpXEfOxQ70jxLTxkTyw bytestring-0.11.5.3
    case-insensitive-1.2.1.0-BBd0FN3VG9pHwba5nfbZ8v
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    clientsession-0.9.2.0-8FF7n7u1ysRVuzYlvJFvN
    conduit-1.3.6.1-86fl8mgs0PcICSp2A4xyva
    conduit-extra-1.3.6-E0orZ3VxcGP3f1095Bo2Ko containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm deepseq-1.4.8.0
    entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    fast-logger-3.1.2-GE9ux6OeXUTBZ4Gqb6r8t8
    http-types-0.12.4-1DZFzfvJVK9AHfgKU8FkY3
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    monad-logger-0.3.41-8f5WrtCEAAaJAwYfnZ9RTa mtl-2.2.2
    parsec-3.1.16.1 path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    primitive-0.8.0.0-CgxKCR9ULfZ73CnNdOTvCD
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD
    shakespeare-2.1.0.1-AD7UIKDnOIUxdqDNmAzti template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.3-9Tj09IRjFnyE6cgV0AVkT
    unliftio-0.2.25.1-LfkN9oBuVsC1PSAv8s4AS5
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O
    wai-3.2.4-LaZv3Kj0Ed9gV12y2mMCG
    wai-extra-3.1.16-I7ARULvVS8bK906k5FQwhX
    wai-logger-2.5.0-IEJ1BDozKwc6Z14LwYmPNh
    warp-3.3.30-7VYQ2rBma143qilyrShCXv
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
